==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/selection/impl/ACT_SELSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.selection.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SEL;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SELSet;
import io.ciera.tool.sql.ooaofooa.selection.ChainLinkSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedBySet;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedWhereSet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ChainLinkSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.SelectRelatedBySetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.SelectRelatedWhereSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class ACT_SELSetImpl extends InstanceSet<ACT_SELSet,ACT_SEL> implements ACT_SELSet {

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setCardinality( String m_cardinality ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setCardinality( m_cardinality );
    }
    @Override
    public void setIs_implicit( boolean m_is_implicit ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setIs_implicit( m_is_implicit );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( ACT_SEL act_sel : this ) act_smtset.add( act_sel.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R613_starting_point_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ACT_SEL act_sel : this ) valueset.add( act_sel.R613_starting_point_Value() );
        return valueset;
    }
    @Override
    public ChainLinkSet R637_starts_with_ChainLink() throws XtumlException {
        ChainLinkSet chainlinkset = new ChainLinkSetImpl();
        for ( ACT_SEL act_sel : this ) chainlinkset.add( act_sel.R637_starts_with_ChainLink() );
        return chainlinkset;
    }
    @Override
    public V_VARSet R638_selection_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( ACT_SEL act_sel : this ) v_varset.add( act_sel.R638_selection_V_VAR() );
        return v_varset;
    }
    @Override
    public SelectRelatedBySet R664_is_a_SelectRelatedBy() throws XtumlException {
        SelectRelatedBySet selectrelatedbyset = new SelectRelatedBySetImpl();
        for ( ACT_SEL act_sel : this ) selectrelatedbyset.add( act_sel.R664_is_a_SelectRelatedBy() );
        return selectrelatedbyset;
    }
    @Override
    public SelectRelatedWhereSet R664_is_a_SelectRelatedWhere() throws XtumlException {
        SelectRelatedWhereSet selectrelatedwhereset = new SelectRelatedWhereSetImpl();
        for ( ACT_SEL act_sel : this ) selectrelatedwhereset.add( act_sel.R664_is_a_SelectRelatedWhere() );
        return selectrelatedwhereset;
    }


    @Override
    public ACT_SEL nullElement() {
        return ACT_SELImpl.EMPTY_ACT_SEL;
    }

    @Override
    public ACT_SELSet emptySet() {
      return new ACT_SELSetImpl();
    }

    @Override
    public ACT_SELSet value() {
        return this;
    }

    @Override
    public List<ACT_SEL> elements() {
        return Arrays.asList(toArray(new ACT_SEL[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/selection/impl/ACT_SELSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.selection.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SEL;
import io.ciera.tool.sql.ooaofooa.selection.ACT_SELSet;
import io.ciera.tool.sql.ooaofooa.selection.ChainLinkSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedBySet;
import io.ciera.tool.sql.ooaofooa.selection.SelectRelatedWhereSet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ChainLinkSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.SelectRelatedBySetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.SelectRelatedWhereSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ACT_SELSetImpl extends InstanceSet<ACT_SELSet,ACT_SEL> implements ACT_SELSet {

    public ACT_SELSetImpl() {
    }

    public ACT_SELSetImpl(Comparator<? super ACT_SEL> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setCardinality( String m_cardinality ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setCardinality( m_cardinality );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setIs_implicit( boolean m_is_implicit ) throws XtumlException {
        for ( ACT_SEL act_sel : this ) act_sel.setIs_implicit( m_is_implicit );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( ACT_SEL act_sel : this ) act_smtset.add( act_sel.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R613_starting_point_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ACT_SEL act_sel : this ) valueset.add( act_sel.R613_starting_point_Value() );
        return valueset;
    }
    @Override
    public ChainLinkSet R637_starts_with_ChainLink() throws XtumlException {
        ChainLinkSet chainlinkset = new ChainLinkSetImpl();
        for ( ACT_SEL act_sel : this ) chainlinkset.add( act_sel.R637_starts_with_ChainLink() );
        return chainlinkset;
    }
    @Override
    public V_VARSet R638_selection_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( ACT_SEL act_sel : this ) v_varset.add( act_sel.R638_selection_V_VAR() );
        return v_varset;
    }
    @Override
    public SelectRelatedBySet R664_is_a_SelectRelatedBy() throws XtumlException {
        SelectRelatedBySet selectrelatedbyset = new SelectRelatedBySetImpl();
        for ( ACT_SEL act_sel : this ) selectrelatedbyset.add( act_sel.R664_is_a_SelectRelatedBy() );
        return selectrelatedbyset;
    }
    @Override
    public SelectRelatedWhereSet R664_is_a_SelectRelatedWhere() throws XtumlException {
        SelectRelatedWhereSet selectrelatedwhereset = new SelectRelatedWhereSetImpl();
        for ( ACT_SEL act_sel : this ) selectrelatedwhereset.add( act_sel.R664_is_a_SelectRelatedWhere() );
        return selectrelatedwhereset;
    }


    @Override
    public ACT_SEL nullElement() {
        return ACT_SELImpl.EMPTY_ACT_SEL;
    }

    @Override
    public ACT_SELSet emptySet() {
      return new ACT_SELSetImpl();
    }

    @Override
    public ACT_SELSet emptySet(Comparator<? super ACT_SEL> comp) {
      return new ACT_SELSetImpl(comp);
    }

    @Override
    public ACT_SELSet value() {
        return this;
    }

    @Override
    public List<ACT_SEL> elements() {
        return Arrays.asList(toArray(new ACT_SEL[0]));
    }

}
